## cdist-tutorial(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-tutorial - a guided introduction into cdist

## 2. INTRODUCTION

This document gives you a pointer on what to read in which order and is thus a "guide to the right locations". So in case you are just starting, just "begin at the beginning" (Brave New World). You can see the target audience in [] brackets after the description.

cdist-quickstart
  New to cdist? Want to get your hands dirty? Read this. [beginner]
cdist-bootstrap
  The comprehensive guide to your first cdist installation [beginner]
cdist-manifest
  Learn how to define which hosts get which configurations [beginner]
cdist-type
  Understand how types are working and created [intermediate]
cdist-best-practice
  Hints from real life experience to help you to organise cdist [intermediate]
cdist-reference
  The type, explorers and environment variables reference [intermediate]
cdist-explorer
  Interested in getting more information about the target system? [intermediate]
cdist-stages
  Understand the internal workflow of cdist. [advanced]
cdist-hacker
  README, if you want to extend or modify cdist. [hacker]

## 3. SEE ALSO

- cdist(1)
- cdist-type(7)
- cdist-best-practice(7)
- cdist-stages(7)
- Brave New World by Aldous Huxley

## 4. COPYING

Copyright (C) 2011-2012 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).